docs

package
v0.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package docs provides the content of github pages at https://gregoryv.github.io/draw/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllShapes

func AllShapes() *design.Diagram

func ExampleActivityDiagram

func ExampleActivityDiagram() *design.ActivityDiagram

func ExampleC4SystemContextDiagram

func ExampleC4SystemContextDiagram() *design.Diagram

func ExampleClassDiagram

func ExampleClassDiagram() *design.ClassDiagram

func ExampleDiagram

func ExampleDiagram() *design.Diagram

func ExampleGanttChart

func ExampleGanttChart() *design.GanttChart

func ExampleSequenceDiagram

func ExampleSequenceDiagram() *design.SequenceDiagram

func ExampleSmallClassDiagram

func ExampleSmallClassDiagram() *design.ClassDiagram

func LoadFile

func LoadFile(filename string, span ...int) *Element

LoadFile returns a pre web element wrapping the contents from the given file. If to == -1 all lines to the end of file are returned.

func NewProjectArticle

func NewProjectArticle() *Element

func NewProjectsPage

func NewProjectsPage() *Page

func Theme

func Theme() *CSS

Types

type Door

type Door struct {
	Material string
}

func (*Door) Materials

func (me *Door) Materials() []string

type House

type House struct {
	Frontdoor Door      // aggregation
	Windows   []*Window // composition
}

func (*House) Rooms

func (me *House) Rooms() int

type Part

type Part interface {
	Materials() []string
}

type Window

type Window struct {
	Model string
}

func (*Window) Materials

func (me *Window) Materials() []string

Source Files

  • activity_example.go
  • c4_example.go
  • class_example.go
  • example_diagrams.go
  • house.go
  • package.go
  • sequence_example.go
  • small_example.go
  • theme.go

Jump to